==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/HouseMedicalCircleCheck.md <==
# HouseMedicalCircleCheck


```text
fontawesome-6/Solid/HouseMedicalCircleCheck
```

```text
include('fontawesome-6/Solid/HouseMedicalCircleCheck')
```



| Illustration | HouseMedicalCircleCheck |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HouseMedicalCircleCheck.png) | ![illustration for HouseMedicalCircleCheck](../../fontawesome-6/Solid/HouseMedicalCircleCheck.Local.png) |




## HouseMedicalCircleCheck

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleCheck
include('fontawesome-6/Solid/HouseMedicalCircleCheck')

' renders the element
HouseMedicalCircleCheck('HouseMedicalCircleCheck', 'House Medical Circle Check', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleCheck
include('fontawesome-6/Solid/HouseMedicalCircleCheck')

' renders the element
HouseMedicalCircleCheck('HouseMedicalCircleCheck', 'House Medical Circle Check', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/HouseMedicalCircleCheck.md <==
# HouseMedicalCircleCheck


```text
fontawesome-6/Solid/HouseMedicalCircleCheck
```

```text
include('fontawesome-6/Solid/HouseMedicalCircleCheck')
```



| Illustration | HouseMedicalCircleCheck |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HouseMedicalCircleCheck.png) | ![illustration for HouseMedicalCircleCheck](../../fontawesome-6/Solid/HouseMedicalCircleCheck.Local.png) |




## HouseMedicalCircleCheck

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleCheck
include('fontawesome-6/Solid/HouseMedicalCircleCheck')

' renders the element
HouseMedicalCircleCheck('HouseMedicalCircleCheck', 'House Medical Circle Check', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleCheck
include('fontawesome-6/Solid/HouseMedicalCircleCheck')

' renders the element
HouseMedicalCircleCheck('HouseMedicalCircleCheck', 'House Medical Circle Check', 'an optional tech label', 'an optional description')
@enduml
```
